// Checks for bad user input
function checkUser() {
    var user = document.getElementById("username");
    var userMsg = document.getElementById("userMsg");
    var length = user.value.length;
    var pos = user.value.search(/[A-Za-z]\w*/);

    if (pos !== 0) {
        user.style.borderColor = "red";
        if (userMsg) {
            userMsg.innerHTML = "Invalid Username!";
            userMsg.classList.remove("valid");
            userMsg.classList.add("invalid");
        }
    } else {
        if (length > 50 || length < 6) {
            user.style.borderColor = "red";
            if (userMsg) {
                userMsg.innerHTML = "Invalid Username!";
                userMsg.classList.remove("valid");
                userMsg.classList.add("invalid");
            }
        } else {
            user.style.borderColor = "green";
            if (userMsg) {
                userMsg.innerHTML = "";
                userMsg.classList.add("valid");
            }
        }
    }
}

// Checks for bad password input
function checkPass() {
    var pass = document.getElementById("password");
    var passMsg = document.getElementById("passMsg");
    var length = pass.value.length;
    // The regular expression was found from this link:
    // https://stackoverflow.com/questions/19605150/regex-for-password-must-contain-at-least-eight-characters-at-least-one-number-a
    var pos = pass.value.search(/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[!@#$%^&*])[A-Za-z\d!@#$%^&*]{8,}$/);

    if (pos !== 0) {
        pass.style.borderColor = "red";
        if (passMsg) {
            passMsg.innerHTML = "Invalid Password, requirements:<br/>" + "1 capital <br/>"
                + "1 lowercase <br/>" + "1 digit <br/>" + "1 special character";
            passMsg.classList.remove("valid");
            passMsg.classList.add("invalid");
        }
    } else {
        if (length > 50 || length < 8) {
            pass.style.borderColor = "red";
            if (passMsg) {
                passMsg.innerHTML = "Invalid Password!";
                passMsg.classList.remove("valid");
                passMsg.classList.add("invalid");
            }
        } else {
            pass.style.borderColor = "green";
            if (passMsg) {
                passMsg.innerHTML = "";
                passMsg.classList.add("valid");
            }
        }
    }
}

// Checks if the first password is equivalent to the second password
function checkRepeatPass() {
    var pass = document.getElementById("password");
    var pass2 = document.getElementById("repeatPassword");
    var pass2Msg = document.getElementById("pass2Msg");

    if ((pass.value) !== (pass2.value)) {
        pass2.style.borderColor = "red";
        if (pass2Msg) {
            pass2Msg.innerHTML = "Password does not match!";
            pass2Msg.classList.remove("valid");
            pass2Msg.classList.add("invalid");
        }
    } else {
        if (pass2.value === "") {
            pass2.style.borderColor = "red";
            if (pass2Msg) {
                pass2Msg.innerHTML = "Nothing was entered!";
                pass2Msg.classList.remove("valid");
                pass2Msg.classList.add("invalid");
            }
        } else {
            pass2.style.borderColor = "green";
            if (pass2Msg) {
                pass2Msg.innerHTML = "";
                pass2Msg.classList.add("valid");
            }
        }
    }
}

// Checks the first name form
function checkFirstName() {
    var first = document.getElementById("firstName");
    var firstNameMsg = document.getElementById("firstNameMsg");
    var length = first.value.length;

    if (length > 50 || length < 1) {
        first.style.borderColor = "red";
        if (firstNameMsg) {
            firstNameMsg.innerHTML = "Invalid First name!";
            firstNameMsg.classList.remove("valid");
            firstNameMsg.classList.add("invalid");
        }
    } else {
        first.style.borderColor = "green";
        if (firstNameMsg) {
            firstNameMsg.innerHTML = "";
            firstNameMsg.classList.add("valid");
        }
    }
}

// Checks the last name form
function checkLastName() {
    var last = document.getElementById("lastName");
    var lastNameMsg = document.getElementById("lastNameMsg");
    var length = last.value.length;

    if (length > 50 || length < 1) {
        last.style.borderColor = "red";
        if (lastNameMsg) {
            lastNameMsg.innerHTML = "Invalid Last name!";
            lastNameMsg.classList.remove("valid");
            lastNameMsg.classList.add("invalid");
        }
    } else {
        last.style.borderColor = "green";
        if (lastNameMsg) {
            lastNameMsg.innerHTML = "";
            lastNameMsg.classList.add("valid");
        }
    }
}

// Checks the first address
function checkAddress1() {
    var addressOne = document.getElementById("address1");
    var addr1Msg = document.getElementById("addr1Msg");
    var length = addressOne.value.length;

    if (length > 100 || length < 1) {
        addressOne.style.borderColor = "red";
        if (addr1Msg) {
            addr1Msg.innerHTML = "Invalid Address!";
            addr1Msg.classList.remove("valid");
            addr1Msg.classList.add("invalid");
        }
    } else {
        addressOne.style.borderColor = "green";
        if (addr1Msg) {
            addr1Msg.innerHTML = "";
            addr1Msg.classList.add("valid");
        }
    }
}

// Does not check the second address, this is optional.
// If it is correct, change color to green
function checkAddress2() {
    var addressTwo = document.getElementById("address2");
    var length = addressTwo.value.length;

    if (length > 100 || length < 1) {
        addressTwo.style.borderColor = "gray";
    } else {
        addressTwo.style.borderColor = "green";
    }
}

// Check the city
function checkCity() {
    var city = document.getElementById("city");
    var cityMsg = document.getElementById("cityMsg");
    var length = city.value.length;

    if (length > 100 || length < 1) {
        city.style.borderColor = "red";
        if (cityMsg) {
            cityMsg.innerHTML = "Invalid City!";
            cityMsg.classList.remove("valid");
            cityMsg.classList.add("invalid");
        }
    } else {
        city.style.borderColor = "green";
        if (cityMsg) {
            cityMsg.innerHTML = "";
            cityMsg.classList.add("valid");
        }
    }
}

// Make sure that the state has been chosen
function checkState() {
    var state = document.getElementById("state");
    var stateMsg = document.getElementById("stateMsg");
    var length = state.value.length;

    if (length > 52 || length < 1) {
        state.style.borderColor = "red";
        if (stateMsg) {
            stateMsg.innerHTML = "Please select a state!";
            stateMsg.classList.remove("valid");
            stateMsg.classList.add("invalid");
        }
    } else {
        if (state.value === "") {
            state.style.borderColor = "red";
            if (stateMsg) {
                stateMsg.innerHTML = "Please select a state!";
                stateMsg.classList.remove("valid");
                stateMsg.classList.add("invalid");
            }
        } else {
            state.style.borderColor = "green";
            if (stateMsg) {
                stateMsg.innerHTML = "";
                stateMsg.classList.add("valid");
            }
        }
    }
}

// Make sure the zip code follows the regex below
function checkZipCode(zip) {
    var zipMsg = document.getElementById("zipMsg");
    var zipVal = String(zip.value).trim();
    // Found the following regex at this link:
    // https://stackoverflow.com/questions/2577236/regex-for-zip-code
    var pos = zipVal.search(/^\d{5}(?:-\d{4})?$/);
    if (pos > -1) {
        zip.style.borderColor = "green";
        if (zipMsg) {
            zipMsg.innerHTML = "";
            zipMsg.classList.add("valid");
        }
    } else {
        zip.style.borderColor = "red";
        if (zipMsg) {
            zipMsg.innerHTML = "Invalid Zipcode!";
            zipMsg.classList.remove("valid");
            zipMsg.classList.add("invalid");
        }
    }
}

// Checks the phone number to see if it is in the right form
function checkPhoneNumber(phone) {
    var phoneVal = String(phone.value).trim();
    var phoneMsg = document.getElementById("phoneMsg");
    var pos = phoneVal.search(/^\(\d{3}\)\s\d{3}-\d{4}/);
    if (pos > -1) {
        phone.style.borderColor = "green";
        if (phoneMsg) {
            phoneMsg.innerHTML = "";
            phoneMsg.classList.add("valid");
        }
    } else {
        phone.style.borderColor = "red";
        if (phoneMsg) {
            phoneMsg.innerHTML = "Invalid Phone number!";
            phoneMsg.classList.remove("valid");
            phoneMsg.classList.add("invalid");
        }
    }
}

// Checks the email to see if it is in the right form
function checkEmail(email) {
    var emailVal = String(email.value).trim();
    var emailMsg = document.getElementById("emailMsg");
    var pos = emailVal.search(/^\S+@\S+\.\S+$/);
    if (pos > -1) {
        email.style.borderColor = "green";
        if (emailMsg) {
            emailMsg.innerHTML = "";
            emailMsg.classList.add("valid");
        }
    } else {
        email.style.borderColor = "red";
        if (emailMsg) {
            emailMsg.innerHTML = "Invalid Email!";
            emailMsg.classList.remove("valid");
            emailMsg.classList.add("invalid");
        }
    }
}

// Makes sure that gender is selected
function checkGender() {
    var male = document.getElementById("maleGender");
    var female = document.getElementById("femaleGender");
    var other = document.getElementById("otherGender");

    var maleLabel = document.getElementById("maleLabel");
    var femaleLabel = document.getElementById("femaleLabel");
    var otherLabel = document.getElementById("otherLabel");

    var genderLabel = document.getElementById("genderLabel");

    if (male.checked) {
        maleLabel.style.color = "green";
        genderLabel.style.color = "";
        if (!female.checked) {
            femaleLabel.style.color = "";
        }
        if (!other.checked) {
            otherLabel.style.color = "";
        }
    } else if (female.checked) {
        femaleLabel.style.color = "green";
        genderLabel.style.color = "";
        if (!male.checked) {
            maleLabel.style.color = "";
        }
        if (!otherLabel.checked) {
            otherLabel.style.color = "";
        }
    } else if (other.checked) {
        otherLabel.style.color = "green";
        if (!male.checked) {
            maleLabel.style.color = "";
        }
        if (!female.checked) {
            femaleLabel.style.color = "";
        }
    }
}

// Makes sure that marital status is checked
function checkMaritalStatus() {
    var single = document.getElementById("singleStatus");
    var married = document.getElementById("marriedStatus");

    var singleLabel = document.getElementById("singleLabel");
    var marriedLabel = document.getElementById("marriedLabel");

    var marriedOrNot = document.getElementById("maritalLabel");

    if (single.checked) {
        singleLabel.style.color = "green";
        marriedOrNot.style.color = "";
        if (!married.checked) {
            marriedLabel.style.color = "";
        }
    } else if (married.checked) {
        marriedLabel.style.color = "green";
        marriedOrNot.style.color = "";
        if (!single.checked) {
            singleLabel.style.color = "";
        }
    }
}

// Makes sure that all of them are validated on submit
function checkCheckers() {
    document.getElementById("username").onblur = checkUser;
    document.getElementById("password").onblur = checkPass;
    document.getElementById("repeatPassword").onblur = checkRepeatPass;
    document.getElementById("firstName").onblur = checkFirstName;
    document.getElementById("lastName").onblur = checkLastName;
    document.getElementById("address1").onblur = checkAddress1;
    document.getElementById("address2").onblur = checkAddress2;
    document.getElementById("city").onblur = checkCity;
    document.getElementById("state").onblur = checkState;
    document.getElementById("zipCode").onblur = checkZipCode;
    document.getElementById("phoneNumber").onblur = checkPhoneNumber;
    document.getElementById("email").onblur = checkEmail;
    document.getElementById("maleGender").onblur = checkGender;
    document.getElementById("femaleGender").onblur = checkGender;
    document.getElementById("otherGender").onblur = checkGender;
    document.getElementById("singleStatus").onblur = checkMaritalStatus;
    document.getElementById("marriedStatus").onblur = checkMaritalStatus;
}