<?php
// define variables and set to empty values

$usernameErr = $passwordErr = $repeatPasswordErr = $firstNameErr = $lastNameErr = $address1Err = $address2Err =
$cityErr = $stateErr = $zipCodeErr = $phoneNumberErr = $emailErr = $genderErr = $maritalStatusErr = $birthDayErr = "";
$username = $password = $repeatPassword = $firstName = $lastName = $address1 = $address2 =
$city = $state = $zipCode = $phoneNumber = $email = $gender = $maritalStatus = $birthDay = "";
$isValid = false;

if ($_SERVER["REQUEST_METHOD"] == "POST") {

    $isValid = true;

    $username = clean_input($_POST["username"]);
    if (empty($username)) {
        $usernameErr = "* Username is required";
        $isValid = false;
    } else {
        if (strlen($username) > 50 || strlen($username) < 6) {
            $usernameErr = "* Something went wrong, try again";
            $isValid = false;
        }
    }


    $password = clean_input($_POST["password"]);
    if (empty($username)) {
        $passwordErr = "* Password is required";
        $isValid = false;
    } else {
        // check if name only contains letters and whitespace
        if (!preg_match("/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[!@#$%^&*])[A-Za-z\d!@#$%^&*]{8,}$/", $password)) {
            /*
            The preg_match() function searches a string for pattern,
            returning true if the pattern exists, and false otherwise.
            */
            $passwordErr = "* Missing: 1 capital, 1 lowercase, 1 digit, 1 special character";
            $isValid = false;
        }
    }

    $repeatPassword = clean_input($_POST["repeatPassword"]);
    if (empty($repeatPassword)) {
        $repeatPasswordErr = "* Type your password again";
        $isValid = false;
    } else {
        if ($password != $repeatPassword) {
            $repeatPasswordErr = "* Passwords do match, try again";
            $isValid = false;
        }
    }

    $firstName = clean_input($_POST["firstName"]);
    if (empty($firstName)) {
        $firstNameErr = "* First name required";
        $isValid = false;
    } else {
        // check if name only contains letters and whitespace
        if (!preg_match("/^[a-zA-Z ]+$/", $firstName)) {
            /*
            The preg_match() function searches a string for pattern,
            returning true if the pattern exists, and false otherwise.
            */
            $firstNameErr = "* Only letters and spaces allowed";
            $isValid = false;
        }
    }

    $lastName = clean_input($_POST["lastName"]);
    if (empty($lastName)) {
        $lastNameErr = "* Last name required";
        $isValid = false;
    } else {
        // check if name only contains letters and whitespace
        if (!preg_match("/^[a-zA-Z ]+$/", $lastName)) {
            /*
            The preg_match() function searches a string for pattern,
            returning true if the pattern exists, and false otherwise.
            */
            $firstNameErr = "* Only letters and spaces allowed";
            $isValid = false;
        }
    }

    $address1 = clean_input($_POST["address1"]);
    if (empty($address1)) {
        $address1Err = "* Address is required";
        $isValid = false;
    } else {
        if (strlen($address1) > 100 || strlen($address1) < 1) {
            $address1Err = "* Something went wrong, try again";
            $isValid = false;
        }
    }

    $city = clean_input($_POST["city"]);
    if (empty($city)) {
        $cityErr = "* City is required";
        $isValid = false;
    } else {
        if (strlen($city) > 50 || strlen($city) < 1) {
            $cityErr = "* Something went wrong, try again";
            $isValid = false;
        }
    }

    if (isset($_POST["state"])) {
        $state = clean_input($_POST["state"]);
        if (empty($_POST["state"])) {
            $stateErr = "* State is required";
            $isValid = false;
        }
    } else {
        $stateErr = "* State is required";
        $isValid = false;
    }

    $zipCode = clean_input($_POST["zipCode"]);
    if (empty($zipCode)) {
        $zipCodeErr = "* Zip Code required";
        $isValid = false;
    } else {
        // check if name only contains letters and whitespace
        if (!preg_match("/^\d{5}(?:-\d{4})?$/", $zipCode)) {
            /*
            The preg_match() function searches a string for pattern,
            returning true if the pattern exists, and false otherwise.
            */
            $zipCodeErr = "* 5 digit Zip Code required";
            $isValid = false;
        }
    }

    $phoneNumber = clean_input($_POST["phoneNumber"]);
    if (empty($phoneNumber)) {
        $phoneNumberErr = "* Phone Number required";
        $isValid = false;
    } else {
        if (!preg_match("/^\(\d{3}\)\s\d{3}-\d{4}/", $phoneNumber)) {
            $phoneNumberErr = "* Phone number required";
            $isValid = false;
        }
    }

    $email = clean_input($_POST["email"]);
    if (empty($email)) {
        $emailErr = "* Email is required";
        $isValid = false;
    } else {
        // check if e-mail address is well-formed
        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            /*
            The filter_var() function is the easiest and safest way
            to check whether an email address is well-formed.
            */
            $emailErr = "* Invalid email format";
            $isValid = false;
        }
    }

    if (isset($_POST["state"])) {
        $state = clean_input($_POST["state"]);
        if (empty($_POST["state"])) {
            $stateErr = "* State is required";
            $isValid = false;
        }
    } else {
        $stateErr = "* State is required";
        $isValid = false;
    }

    if (empty($_POST["gender"])) {
        $genderErr = "* Gender is required";
        $isValid = false;
    } else {
        $gender = clean_input($_POST["gender"]);
    }

    if (empty($_POST["maritalStatus"])) {
        $maritalStatusErr = "* Marital status is required";
        $isValid = false;
    } else {
        $maritalStatus = clean_input($_POST["maritalStatus"]);
    }

    if (isset($_POST["birthDay"])) {
        $birthDay = clean_input($_POST["birthDay"]);
        if (empty($_POST["birthDay"])) {
            $birthDayErr = "* Birthday is required";
            $isValid = false;
        }
    }

}

function clean_input($data)
{
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    return $data;
}

